==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/GetHuntCommentPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.GetHuntCommentPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property huntCommentId The hunt comment id (GUID)
 * @property huntId The hunt id (GUID)
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property workspaceName The name of the workspace.
 */
public data class GetHuntCommentPlainArgs(
    public val huntCommentId: String,
    public val huntId: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.GetHuntCommentPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.GetHuntCommentPlainArgs =
        com.pulumi.azurenative.securityinsights.inputs.GetHuntCommentPlainArgs.builder()
            .huntCommentId(huntCommentId.let({ args0 -> args0 }))
            .huntId(huntId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetHuntCommentPlainArgs].
 */
@PulumiTagMarker
public class GetHuntCommentPlainArgsBuilder internal constructor() {
    private var huntCommentId: String? = null

    private var huntId: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value The hunt comment id (GUID)
     */
    @JvmName("udfjgkdirlgvbnbh")
    public suspend fun huntCommentId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.huntCommentId = mapped
    }

    /**
     * @param value The hunt id (GUID)
     */
    @JvmName("imlptiucisutnjfh")
    public suspend fun huntId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.huntId = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("xhgqlqenntuvxfqn")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("kojaktwmraicmcea")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetHuntCommentPlainArgs = GetHuntCommentPlainArgs(
        huntCommentId = huntCommentId ?: throw PulumiNullFieldException("huntCommentId"),
        huntId = huntId ?: throw PulumiNullFieldException("huntId"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/GetHuntCommentPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.GetHuntCommentPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property huntCommentId The hunt comment id (GUID)
 * @property huntId The hunt id (GUID)
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property workspaceName The name of the workspace.
 */
public data class GetHuntCommentPlainArgs(
    public val huntCommentId: String,
    public val huntId: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.GetHuntCommentPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.GetHuntCommentPlainArgs =
        com.pulumi.azurenative.securityinsights.inputs.GetHuntCommentPlainArgs.builder()
            .huntCommentId(huntCommentId.let({ args0 -> args0 }))
            .huntId(huntId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetHuntCommentPlainArgs].
 */
@PulumiTagMarker
public class GetHuntCommentPlainArgsBuilder internal constructor() {
    private var huntCommentId: String? = null

    private var huntId: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value The hunt comment id (GUID)
     */
    @JvmName("ljecdebsxgawxcps")
    public suspend fun huntCommentId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.huntCommentId = mapped
    }

    /**
     * @param value The hunt id (GUID)
     */
    @JvmName("jdvidjlvenjlmben")
    public suspend fun huntId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.huntId = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("sytdabguxghrocsc")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("jqpwhuoqiqyiiwtd")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetHuntCommentPlainArgs = GetHuntCommentPlainArgs(
        huntCommentId = huntCommentId ?: throw PulumiNullFieldException("huntCommentId"),
        huntId = huntId ?: throw PulumiNullFieldException("huntId"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}
